==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ssmincidents/kotlin/outputs/ResponsePlanIncidentTemplate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ssmincidents.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 *
 * @property dedupeString A string used to stop Incident Manager from creating multiple incident records for the same incident.
 * @property impact The impact value of a generated incident. The following values are supported:
 * @property incidentTags The tags assigned to an incident template. When an incident starts, Incident Manager assigns the tags specified in the template to the incident.
 * @property notificationTargets The Amazon Simple Notification Service (Amazon SNS) targets that this incident notifies when it is updated. The `notification_target` configuration block supports the following argument:
 * @property summary The summary of an incident.
 * @property title The title of a generated incident.
 */
public data class ResponsePlanIncidentTemplate(
    public val dedupeString: String? = null,
    public val impact: Int,
    public val incidentTags: Map<String, String>? = null,
    public val notificationTargets: List<ResponsePlanIncidentTemplateNotificationTarget>? = null,
    public val summary: String? = null,
    public val title: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ssmincidents.outputs.ResponsePlanIncidentTemplate):
            ResponsePlanIncidentTemplate = ResponsePlanIncidentTemplate(
            dedupeString = javaType.dedupeString().map({ args0 -> args0 }).orElse(null),
            impact = javaType.impact(),
            incidentTags = javaType.incidentTags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            notificationTargets = javaType.notificationTargets().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.ssmincidents.kotlin.outputs.ResponsePlanIncidentTemplateNotificationTarget.Companion.toKotlin(args0)
                })
            }),
            summary = javaType.summary().map({ args0 -> args0 }).orElse(null),
            title = javaType.title(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ssmincidents/kotlin/outputs/ResponsePlanIncidentTemplate.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ssmincidents.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 *
 * @property dedupeString A string used to stop Incident Manager from creating multiple incident records for the same incident.
 * @property impact The impact value of a generated incident. The following values are supported:
 * @property incidentTags The tags assigned to an incident template. When an incident starts, Incident Manager assigns the tags specified in the template to the incident.
 * @property notificationTargets The Amazon Simple Notification Service (Amazon SNS) targets that this incident notifies when it is updated. The `notification_target` configuration block supports the following argument:
 * @property summary The summary of an incident.
 * @property title The title of a generated incident.
 */
public data class ResponsePlanIncidentTemplate(
    public val dedupeString: String? = null,
    public val impact: Int,
    public val incidentTags: Map<String, String>? = null,
    public val notificationTargets: List<ResponsePlanIncidentTemplateNotificationTarget>? = null,
    public val summary: String? = null,
    public val title: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.ssmincidents.outputs.ResponsePlanIncidentTemplate): ResponsePlanIncidentTemplate = ResponsePlanIncidentTemplate(
            dedupeString = javaType.dedupeString().map({ args0 -> args0 }).orElse(null),
            impact = javaType.impact(),
            incidentTags = javaType.incidentTags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            notificationTargets = javaType.notificationTargets().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.ssmincidents.kotlin.outputs.ResponsePlanIncidentTemplateNotificationTarget.Companion.toKotlin(args0)
                })
            }),
            summary = javaType.summary().map({ args0 -> args0 }).orElse(null),
            title = javaType.title(),
        )
    }
}
